##  Overview
SAP ERP is the traditional suite of enterprise software applications developed by SAP to help businesses manage their key processes, such as finance, human resources, procurement, supply chain, and more. SAP ERP 6.0 is a major SAP ERP suite that will be supported until 2030.
SAP ERP is built on the classic R/3 architecture, where "R/3" stands for Real-Time, Three-Tier Architecture. It typically uses a relational database management system (RDBMS) for its back end, such as Microsoft SQL Server, Oracle, or IBM Db2. The suite is primarily deployed on-premise, though some cloud deployment options exist.
This guide focuses on modeling the "old" SAP ERP solutions to support best practices modeling for ERP/ S/4HANA transformation use cases (check the [ERP Transformation](https://help.sap.com/docs/leanix/ea/erp-transformation?locale=en-US&state=PRODUCTION&version=CLOUD "Step-by-step guide for ERP Transformation using SAP LeanIX.") use case guide for details). Follow the general instructions from the [Modeling SAP Cloud Solutions](https://help.sap.com/docs/leanix/ea/modeling-sap-cloud-solutions?locale=en-US&state=PRODUCTION&version=CLOUD "Understand the business and technical perspectives of modeling SAP Cloud Solutions and learn how to model them in SAP LeanIX.") guide while modeling the SAP ERP 6.0 in SAP LeanIX since most of the best practices apply for SAP ERP 6.0 as well.
